@@ -11,7 +11,11 @@ use MIME::Base64 qw(encode_base64 decode_base64);
 use Sys::CPU;
 use Coro::ProcessPool::Process;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
+
+if ($^O eq 'MSWin32') {
+    die 'MSWin32 is not supported';
+}
 
 use fields qw(
     max_procs
@@ -162,6 +166,27 @@ C<max_reqs> can cause this method to yield while a new process is spawned.
 Shuts down all processes and resets state on the process pool. After calling
 this method, the pool is effectively in a new state and may be used normally.
 
+=head1 COMPATIBILITY
+
+C<Coro::ProcessPool> will likely break on Win32 due to missing support for
+non-blocking file descriptors (Win32 can only call C<select> and C<poll> on
+actual network sockets). Without rewriting this as a network server, which
+would impact performance and be really annoying, it is likely this module will
+not support Win32 in the near future.
+
+The following modules will get you started if you wish to explore a synchronous
+process pool on Windows:
+
+=over
+
+=item L<Win32::Process>
+
+=item L<Win32::IPC>
+
+=item L<Win32::Pipe>
+
+=back
+
 =head1 AUTHOR
 
 Jeff Ober mailto:jeffober@gmail.com
